@@ -1,7 +1,9 @@
 mod accumulator;
 mod central_moments;
+mod normalized_central_moments;
 mod storage;
 
 pub use self::accumulator::{Accumulator, SealedSupportedOrder};
 pub use self::central_moments::CentralMoments;
+pub use self::normalized_central_moments::NormalizedCentralMoments;
 pub use self::storage::{calculate_space, Storage};
